﻿Imports ThinkGeo.MapSuite.WpfDesktopEdition
Imports ThinkGeo.MapSuite.Core
Class MainWindow
    Private mcList As New List(Of MyOwnClass)
    Private mylayerOverlay As LayerOverlay = New LayerOverlay()

    Private Sub MainWindow_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded
        wpfMap1.MapUnit = GeographyUnit.DecimalDegree

        Dim worldLayer As ShapeFileFeatureLayer = New ShapeFileFeatureLayer("C:\Program Files (x86)\ThinkGeo\Map Suite Wpf Desktop Evaluation Edition 7.0\Samples\VB Samples\SampleData\Data\Countries02.shp")
        worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1
        worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

        Dim capitalLayer As ShapeFileFeatureLayer = New ShapeFileFeatureLayer("C:\Program Files (x86)\ThinkGeo\Map Suite Wpf Desktop Evaluation Edition 7.0\Samples\VB Samples\SampleData\Data\WorldCapitals.shp")
        capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital3
        capitalLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

        Dim layerOverlay As LayerOverlay = New LayerOverlay()
        layerOverlay.Layers.Add(New BackgroundLayer(New GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)))
        layerOverlay.Layers.Add(worldLayer)
        layerOverlay.Layers.Add(capitalLayer)

        wpfMap1.Overlays.Add(layerOverlay)

        'Load data
        For Each d As String In data
            Dim coordsStr As String() = d.Split("|")
            Dim coordList As New List(Of Coordinate)
            For Each c As String In coordsStr
                Dim coor As New Coordinate(CDbl(c.Split(",")(0)), CDbl(c.Split(",")(1)))
                coordList.Add(coor)
            Next
            Dim moc As New MyOwnClass(coordList, "Lat:" & coordList(0).Lat & Environment.NewLine & "Lon: " & coordList(0).Lon)
            mcList.Add(moc)
        Next

        'Layers for polygons
        wpfMap1.Overlays.Add("MyOverlay", mylayerOverlay)
        Dim MyinMemoryFeatureLayer As New InMemoryFeatureLayer
        MyinMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.StandardColors.Blue)
        MyinMemoryFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
        MyinMemoryFeatureLayer.Open()
        MyinMemoryFeatureLayer.EditTools.BeginTransaction()
        'Add Polys to layer
        For Each poly As MyOwnClass In mcList
            Dim ringShape As New RingShape()
            For Each ppt As Coordinate In poly.PolyPtList
                ringShape.Vertices.Add(New Vertex(ppt.Lon, ppt.Lat))
            Next
            Dim polyShape As New PolygonShape()
            polyShape.OuterRing = ringShape
            Dim f As New Feature(polyShape)
            f.Tag = poly
            MyinMemoryFeatureLayer.EditTools.Add(f)
        Next
        MyinMemoryFeatureLayer.EditTools.CommitTransaction()
        MyinMemoryFeatureLayer.Close()
        mylayerOverlay.Layers.Add("MyIMFL", MyinMemoryFeatureLayer)

        wpfMap1.CurrentExtent = New RectangleShape(-109.5, 40, -108, 39)
        wpfMap1.Refresh()

    End Sub

    Private Sub WpfMap1_MouseMove(ByVal sender As Object, ByVal e As System.Windows.Input.MouseEventArgs) Handles wpfMap1.MouseMove
        Dim imfLayer As InMemoryFeatureLayer = CType(wpfMap1.FindFeatureLayer("MyIMFL"), InMemoryFeatureLayer)
        If imfLayer Is Nothing Then Exit Sub 'No layer exists so exit
        'Define bounary in pixels aroun poygon to trigger tooltip
        Dim screenBuffer As Integer = 5
        'Maintain buffer at any zoom level
        Dim currentPointF As New ScreenPointF(e.GetPosition(wpfMap1).X, e.GetPosition(wpfMap1).Y)
        Dim bufferPointF As New ScreenPointF(currentPointF.X + screenBuffer, currentPointF.Y)
        Dim distanceBuffer As Double = ExtentHelper.GetWorldDistanceBetweenTwoScreenPoints(wpfMap1.CurrentExtent, currentPointF, bufferPointF, wpfMap1.ActualWidth, wpfMap1.ActualHeight, wpfMap1.MapUnit, DistanceUnit.Meter)
        'Make sure there are features
        If imfLayer.InternalFeatures.Count > 0 Then
            'ToWorldCoordinate requires a column name, so just use a dummy or a real name if there is one
            Dim columnNames As New List(Of String)()
            columnNames.Add("dummy")

            Dim features As Collections.ObjectModel.Collection(Of Feature)
            Dim worldPointShape As PointShape = ExtentHelper.ToWorldCoordinate(wpfMap1.CurrentExtent, New ScreenPointF(e.GetPosition(wpfMap1).X, e.GetPosition(wpfMap1).Y), wpfMap1.ActualWidth, wpfMap1.ActualHeight)
            SyncLock imfLayer   'Lock the layer while opening it
                imfLayer.FeatureSource.Open()
                'Get features within the buffer zone distance
                features = imfLayer.FeatureSource.GetFeaturesNearestTo(worldPointShape, wpfMap1.MapUnit, 1, columnNames, distanceBuffer, DistanceUnit.Meter)
                imfLayer.FeatureSource.Close()
            End SyncLock
            If features.Count > 0 Then      'We got some features
                Dim f As Feature = DirectCast(features(0), Feature) 'We are only interested in the first one
                Dim moc As MyOwnClass = DirectCast(f.Tag, MyOwnClass)   'Get the instance of MyOwnClass from the Tag property
                tblMouseOver.Text = moc.TooltipText     'Set the TexBlock text to our tooltip text

                'Show tooltip at top right of pointer, offset by 3 pixels
                tblMouseOver.Margin = New Thickness(Border2.Margin.Left + e.GetPosition(wpfMap1).X + 3 _
                                                    , Border2.Margin.Top + e.GetPosition(wpfMap1).Y - 3 - tblMouseOver.ActualHeight _
                                                    , Border2.Margin.Right - e.GetPosition(wpfMap1).X - 3 _
                                                    , Border2.Margin.Bottom - e.GetPosition(wpfMap1).Y + 3 + tblMouseOver.ActualHeight)
                tblMouseOver.Visibility = Visibility.Visible
            Else
                tblMouseOver.Visibility = Visibility.Hidden
            End If
        Else
            tblMouseOver.Visibility = Visibility.Hidden
        End If
    End Sub

    Private data As String() = New String() { _
        "-108.23383861838,39.0712527532655|-108.234043557072,39.0709825075325|-108.244067248711,39.0754724744459|-108.243759878114,39.0758778692177|-108.23383861838,39.0712527532655", _
"-108.243759878114,39.0758778692177|-108.244067248711,39.0754724744459|-108.254092215917,39.0799615831286|-108.253682438409,39.0805021443843|-108.243759878114,39.0758778692177", _
"-108.253682438409,39.0805021443843|-108.254092215917,39.0799615831286|-108.264118458811,39.0844498333339|-108.263606299413,39.0851255785164|-108.253682438409,39.0805021443843", _
"-108.263606299413,39.0851255785164|-108.264118458811,39.0844498333339|-108.274145977515,39.0889372248152|-108.273531461275,39.0897481713651|-108.263606299413,39.0851255785164", _
"-108.273531461275,39.0897481713651|-108.274145977515,39.0889372248152|-108.284174772154,39.0934237573258|-108.283457924142,39.0943699226814|-108.273531461275,39.0897481713651", _
"-108.283457924142,39.0943699226814|-108.284174772154,39.0934237573258|-108.294204842848,39.0979094306188|-108.293385688163,39.0989908322162|-108.283457924142,39.0943699226814", _
"-108.293385688163,39.0989908322162|-108.294204842848,39.0979094306188|-108.304236189719,39.1023942444475|-108.303314753486,39.1036108997204|-108.293385688163,39.0989908322162", _
"-108.303314753486,39.1036108997204|-108.304236189719,39.1023942444475|-108.31426881289,39.106878198565|-108.313245120259,39.108230124945|-108.303314753486,39.1036108997204", _
"-108.313245120259,39.108230124945|-108.31426881289,39.106878198565|-108.324302712482,39.1113612927245|-108.323176788629,39.1128485076407|-108.313245120259,39.108230124945", _
"-108.323176788629,39.1128485076407|-108.324302712482,39.1113612927245|-108.334337888617,39.1158435266791|-108.333109758743,39.1174660475584|-108.323176788629,39.1128485076407", _
"-108.333109758743,39.1174660475584|-108.334337888617,39.1158435266791|-108.344374341416,39.1203249001818|-108.343044030749,39.1220827444487|-108.333109758743,39.1174660475584", _
"-108.402677010747,39.1497652082542|-108.404619874934,39.147195057875|-108.414665267768,39.151670401297|-108.412620400109,39.1543759969709|-108.402677010747,39.1497652082542", _
"-109.011613547312,39.4294679227024|-109.019731134636,39.4186038439661|-109.029854676671,39.4230261254371|-109.021636685421,39.4340267067314|-109.011613547312,39.4294679227024", _
"-109.021636685421,39.4340267067314|-109.029854676671,39.4230261254371|-109.03997950336,39.4274475293303|-109.031661135225,39.4385846304353|-109.021636685421,39.4340267067314", _
"-109.031661135225,39.4385846304353|-109.03997950336,39.4274475293303|-109.050105614813,39.4318680553964|-109.04168689686,39.4431416935619|-109.031661135225,39.4385846304353", _
"-109.111903971054,39.475017018099|-109.121024377582,39.462787137739|-109.131160771089,39.4672006322041|-109.121940232247,39.4795671875267|-109.111903971054,39.475017018099", _
"-109.121940232247,39.4795671875267|-109.131160771089,39.4672006322041|-109.141298450342,39.4716132465954|-109.131977806496,39.4841164941062|-109.121940232247,39.4795671875267" _
}
End Class
